@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::AnyViewer;
-$Config::Model::Tk::AnyViewer::VERSION = '1.359';
+$Config::Model::Tk::AnyViewer::VERSION = '1.360';
 use strict;
 use warnings;
 use Carp;
@@ -144,7 +144,7 @@ sub update_help {
 
     # work around RT #67306
     my $t = $cw->toplevel->cget('-title');
-    $w->text("\n\n=pod\n\n\n$help\n\n=cut\n\n");
+    $w->text("\n\n=pod\n\n\n=encoding utf8\n\n$help\n\n=cut\n\n");
     $w->toplevel->title($t);
 }
 
