@@ -8,6 +8,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use utf8;
 
 # this file is used by test script
 
@@ -117,7 +118,7 @@
 
 =head1 coucou
 
-Master description . Let's go for a very long description.
+Master description . Let's go for a very long description with utf8 chars: ßéè.
 
 Big class to do:
 
@@ -184,7 +185,7 @@ things.
                     type       => 'leaf',
                     value_type => 'uniline'
                 },
-                summary => 'lista and listb are used to yada yada ',
+                summary => 'lista and listb are used to yada yada with utf8 chars: ßéè',
             },
             [qw/hash_a hash_b/] => {
                 type       => 'hash',
@@ -327,7 +328,7 @@ things.
                 type   => 'leaf',
                 value_type => 'enum' ,
                 choice => [ 'AA' .. 'AE' ],
-                help   => { map { ( $_ => "$_ help") ;} ('AA' .. 'AE') },
+                help   => { map { ( $_ => "$_ help with utf8 ßé²") ;} ('AA' .. 'AE') },
                 description =>
                   'my_plain_check_list nto so helpfull description',
             },
@@ -335,9 +336,9 @@ things.
                 type   => 'leaf',
                 value_type => 'enum' ,
                 choice => [ 'AA' .. 'AE' ],
-                help   => { map { ( $_ => "$_ help") ;} ('AA' .. 'AE') },
+                help   => { map { ( $_ => "$_ help with utf8 ßé²") ;} ('AA' .. 'AE') } ,
                 description =>
-                  "my_plain_check_list not so helpful\n even if long description",
+                  "my_plain_check_list not so helpful\n even if B<long> description 😁",
             },
            my_ref_check_list => {
                 type     => 'check_list',
@@ -402,7 +403,7 @@ things.
         ],
         description => [
             tree_macro    => 'controls behavior of other elements',
-            a_long_string => "long string with \\n in it",
+            a_long_string => "long string with \\n in it and with utf8 chars: ßéè",
             my_reference  => "very long help:\n"
               . "Config::Model enables a project developer to provide an interactive configuration editor to his users. For this he must:
 - describe the structure and constraint of his project's configuration
